==> haskell-tasty-quickcheck-0.10-19-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-tasty-quickcheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tasty-quickcheck
version: 0.10
id: tasty-quickcheck-0.10-IwG8CrdRUbrBUXczkN4boI
key: tasty-quickcheck-0.10-IwG8CrdRUbrBUXczkN4boI
license: MIT
maintainer: Roman Cheplyaka <roma@ro-che.info>
author: Roman Cheplyaka <roma@ro-che.info>
homepage: https://github.com/feuerbach/tasty
synopsis: QuickCheck support for the Tasty test framework.
description:
    QuickCheck support for the Tasty test framework.
category: Testing
abi: 3fd4589a9e6ae39a9e579e653ab1bd84
exposed: True
exposed-modules:
    Test.Tasty.QuickCheck
import-dirs: /usr/lib/ghc-8.4.3/site-local/tasty-quickcheck-0.10
library-dirs: /usr/lib/ghc-8.4.3/site-local/tasty-quickcheck-0.10
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/tasty-quickcheck-0.10
hs-libraries: HStasty-quickcheck-0.10-IwG8CrdRUbrBUXczkN4boI
depends:
    base-4.11.1.0 tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO
    tasty-1.1.0.4-JVxQGtLb8FS2ZJgzdlYC9o
    random-1.1-9LLJAJa4iQFLJiLXBOBXBV
    QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr
    optparse-applicative-0.14.3.0-3858SIdIcA6IDhFDNu1Ke4
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO=4bf567357cce5e796341c1faefad6985
             tasty-1.1.0.4-JVxQGtLb8FS2ZJgzdlYC9o=45655e1f87d1aadd2caf3019f95a0f8e
             random-1.1-9LLJAJa4iQFLJiLXBOBXBV=8df244958947206247b1dd733653312e
             QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr=0b62adbb61d61aac8d449588192e831b
             optparse-applicative-0.14.3.0-3858SIdIcA6IDhFDNu1Ke4=aab631eb7769f669f53846ea7d62d855
haddock-interfaces: /usr/share/doc/haskell-tasty-quickcheck/html/tasty-quickcheck.haddock
haddock-html: /usr/share/doc/haskell-tasty-quickcheck/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tasty-quickcheck-0.10-21-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-tasty-quickcheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tasty-quickcheck
version: 0.10
id: tasty-quickcheck-0.10-5To6zWkgyFlLI3a1KsC7Pz
key: tasty-quickcheck-0.10-5To6zWkgyFlLI3a1KsC7Pz
license: MIT
maintainer: Roman Cheplyaka <roma@ro-che.info>
author: Roman Cheplyaka <roma@ro-che.info>
homepage: https://github.com/feuerbach/tasty
synopsis: QuickCheck support for the Tasty test framework.
description:
    QuickCheck support for the Tasty test framework.
category: Testing
abi: 5d0bd6e1dc41534473598b4301b9d809
exposed: True
exposed-modules:
    Test.Tasty.QuickCheck
import-dirs: /usr/lib/ghc-8.6.1/site-local/tasty-quickcheck-0.10
library-dirs: /usr/lib/ghc-8.6.1/site-local/tasty-quickcheck-0.10
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.1/tasty-quickcheck-0.10
hs-libraries: HStasty-quickcheck-0.10-5To6zWkgyFlLI3a1KsC7Pz
depends:
    QuickCheck-2.11.3-BDoyaQh2Mcq3pIdI4VETKc base-4.12.0.0
    optparse-applicative-0.14.3.0-BVXhkxJuCJ17E9CBbUEb4U
    random-1.1-3ypV4EIycgb35PKjTYYr5q
    tagged-0.8.6-FABECvKnqYbBCttH1EeJvB
    tasty-1.1.0.4-KA2OQv2hxns8llKnTblJO9
haddock-interfaces: /usr/share/doc/haskell-tasty-quickcheck/html/tasty-quickcheck.haddock
haddock-html: /usr/share/doc/haskell-tasty-quickcheck/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
